From 02aabd9d59bbdd51f211fc652500114228f23433 Mon Sep 17 00:00:00 2001
From: Daniel Baumann <daniel.baumann@progress-linux.org>
Date: Tue, 27 Apr 2021 23:24:06 +0200
Subject: [PATCH 05/22] Using update-alternatives to handle /usr/bin/dig.

Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
---
 debian/dnsutils.postinst | 25 +++++++++++++++++++++++++
 debian/dnsutils.prerm    | 23 +++++++++++++++++++++++
 debian/rules             |  7 +++++++
 3 files changed, 55 insertions(+)
 create mode 100644 debian/dnsutils.postinst
 create mode 100644 debian/dnsutils.prerm

diff --git a/debian/dnsutils.postinst b/debian/dnsutils.postinst
new file mode 100644
index 0000000..76a6234
--- /dev/null
+++ b/debian/dnsutils.postinst
@@ -0,0 +1,25 @@
+#!/bin/sh
+
+set -e
+
+case "${1}" in
+	configure)
+		# update-alternatives: dig
+		update-alternatives --quiet \
+			--install /usr/bin/dig dig /usr/bin/dig.bind9 10 \
+			--slave /usr/share/man/man1/dig.1.gz dig.1.gz /usr/share/man/man1/dig.bind9.1.gz
+		;;
+
+	abort-upgrade|abort-remove|abort-deconfigure)
+
+		;;
+
+	*)
+		echo "postinst called with unknown argument \`${1}'" >&2
+		exit 1
+		;;
+esac
+
+#DEBHELPER#
+
+exit 0
diff --git a/debian/dnsutils.prerm b/debian/dnsutils.prerm
new file mode 100644
index 0000000..07589cc
--- /dev/null
+++ b/debian/dnsutils.prerm
@@ -0,0 +1,23 @@
+#!/bin/sh
+
+set -e
+
+case "${1}" in
+	remove|upgrade|deconfigure)
+		# update-alternatives: dig
+		update-alternatives --quiet --remove dig /usr/bin/dig.bind9
+		;;
+
+	failed-upgrade)
+
+		;;
+
+	*)
+		echo "prerm called with unknown argument \`${1}'" >&2
+		exit 1
+		;;
+esac
+
+#DEBHELPER#
+
+exit 0
diff --git a/debian/rules b/debian/rules
index 14071f2..b70f9ed 100755
--- a/debian/rules
+++ b/debian/rules
@@ -98,6 +98,13 @@ override_dh_install:
 	# Install apparmor profile
 	dh_apparmor -pbind9 --profile-name=usr.sbin.named
 
+	# update-alternatives: dig
+	if [ -e debian/dnsutils/usr/bin/dig ]; \
+	then \
+		mv debian/dnsutils/usr/bin/dig debian/dnsutils/usr/bin/dig.bind9; \
+		mv debian/dnsutils/usr/share/man/man1/dig.1 debian/dnsutils/usr/share/man/man1/dig.bind9.1; \
+	fi
+
 override_dh_missing:
 	dh_missing --exclude=.la --exclude=lwresd --exclude=__pycache_ --fail-missing
 
-- 
2.30.2

